@@ -1,9 +1,6 @@
 from firestone.handlers import BaseHandler
 from firestone import exceptions
 from django.contrib.auth import authenticate
-from django.conf import settings
-from django.utils import timezone
-from itsdangerous import TimedJSONWebSignatureSerializer
 
 
 class ObtainJWTHandler(BaseHandler):
@@ -13,9 +10,9 @@ class ObtainJWTHandler(BaseHandler):
     """
     http_methods = ('POST',)
     post_body_fields = ('username', 'password',)
-    
+
     template = {
-        'fields': ('token',) 
+        'fields': ('token',)
     }
 
     def validate(self):
@@ -29,11 +26,7 @@ class ObtainJWTHandler(BaseHandler):
         self.request.data = user
 
     def post(self):
-        s = TimedJSONWebSignatureSerializer(
-            settings.SECRET_KEY, 
-            expires_in=3600*24
-        )
-        token = s.dumps({'iss': self.request.data.id} # ``iss`` symbolizes the issuer(user)
-        
+        s = self.jwt_signer
+        # ``iss`` symbolizes the issuer(user)
+        token = s.dumps({'iss': self.request.data.id})
         return {'token': token}
-
